
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.047.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "ExtUtils::MakeMaker" => 0,
    "Module::Build" => "0.28",
    "perl" => "5.004"
  },
  "dist_abstract" => "Format SQL via the sqlformat.org API",
  "dist_author" => [
    "Olaf Alders <olaf\@wundercounter.com>"
  ],
  "dist_name" => "WebService-SQLFormat",
  "dist_version" => "0.000001",
  "license" => "perl",
  "module_name" => "WebService::SQLFormat",
  "recursive_test_files" => 1,
  "requires" => {
    "JSON::MaybeXS" => 0,
    "LWP::ConsoleLogger::Easy" => 0,
    "LWP::UserAgent" => 0,
    "Moo" => 0,
    "Types::Standard" => 0,
    "Types::URI" => 0,
    "perl" => "5.006"
  },
  "test_requires" => {
    "DDP" => 0,
    "Test2::Bundle::More" => 0,
    "perl" => "5.006",
    "strict" => 0,
    "warnings" => 0
  }
);


my %fallback_build_requires = (
  "DDP" => 0,
  "Module::Build" => "0.28",
  "Test2::Bundle::More" => 0,
  "perl" => "5.006",
  "strict" => 0,
  "warnings" => 0
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
